==> haskell-genvalidity-property-0.5.0.1-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-property
version:              0.5.0.1
visibility:           public
id:                   genvalidity-property-0.5.0.1-G63IDFuewl4HicVa6R5C9V
key:                  genvalidity-property-0.5.0.1-G63IDFuewl4HicVa6R5C9V
license:              MIT
copyright:            Copyright: (c) 2016-2018 Tom Sydney Kerckhove
maintainer:
    syd.kerckhove@gmail.com,
    nick.van.den.broeck666@gmail.com

author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
description:          Standard properties for functions on `Validity` types
category:             Testing
abi:                  0f2984d56beb2d1920843807aa3ec74b
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-8.8.3/site-local/genvalidity-property-0.5.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/genvalidity-property-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.8.3/genvalidity-property-0.5.0.1

hs-libraries:         HSgenvalidity-property-0.5.0.1-G63IDFuewl4HicVa6R5C9V
depends:
    QuickCheck-2.13.2-6162FC0NJtEaNoo7xqAu9 base-4.13.0.0
    genvalidity-0.10.0.2-IQcVeTjVBqv6E9QbW09M6c
    hspec-2.7.1-LQ8iACRexgHtdIZ0BjYyS
    pretty-show-1.10-7q5amcqtFPNELOrR9L3gUm
    validity-0.9.0.3-4g0DbDsg3ME6GNMYtJGvqz

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-property-0.5.0.1-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity-property.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-property
version:              0.5.0.1
visibility:           public
id:                   genvalidity-property-0.5.0.1-IpnMNr1tcfJJoWrUY9h01c
key:                  genvalidity-property-0.5.0.1-IpnMNr1tcfJJoWrUY9h01c
license:              MIT
copyright:            Copyright: (c) 2016-2018 Tom Sydney Kerckhove
maintainer:
    syd.kerckhove@gmail.com,
    nick.van.den.broeck666@gmail.com

author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
description:          Standard properties for functions on `Validity` types
category:             Testing
abi:                  3cab7ee0579bbe97b9cb6940385797a0
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-8.10.1/site-local/genvalidity-property-0.5.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/genvalidity-property-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/genvalidity-property-0.5.0.1

hs-libraries:         HSgenvalidity-property-0.5.0.1-IpnMNr1tcfJJoWrUY9h01c
depends:
    QuickCheck-2.14-ApktXbIbv818f03OoLosyK base-4.14.0.0
    genvalidity-0.11.0.0-LBirlEzLdTBBmgpIflyqnl
    hspec-2.7.1-Ddh0BkDYCkR7uykDDoZ5Ha
    pretty-show-1.10-5aohyDmEADG9yJ0U7kMN1J
    validity-0.11.0.0-3wRpLTxXhUyInWvuoFYfgM

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
